@@ -1,9 +1,12 @@
 #' Get Open Data resources from a dataset
 #'
-#' @description Downloads multiple resources from a dataset on the NHS Open Data platform by dataset name, with optional row limits and context columns.
+#' @description Downloads multiple resources from a dataset on the NHS Open Data
+#'  platform by dataset name, with optional row limits and context columns.
 #'
-#' @param dataset_name Name of the dataset as found on \href{https://www.opendata.nhs.scot/}{NHS Open Data platform} (character).
-#' @param max_resources (optional) The maximum number of resources to return (integer). If not set, all resources are returned.
+#' @param dataset_name Name of the dataset as found on the
+#' [NHS Open Data platform](https://www.opendata.nhs.scot) (character).
+#' @param max_resources (optional) The maximum number of resources to return
+#' (integer). If not set, all resources are returned.
 #' @inheritParams get_resource
 #'
 #' @seealso [get_resource()] for downloading a single resource from a dataset.
@@ -11,8 +14,10 @@
 #' @return A [tibble][tibble::tibble-package] with the data.
 #' @export
 #'
-#' @examples
+#' @examplesIf isTRUE(length(curl::nslookup("www.opendata.nhs.scot", error = FALSE)) > 0L)
+#' \dontrun{
 #' get_dataset("gp-practice-populations", max_resources = 2, rows = 10)
+#' }
 get_dataset <- function(
   dataset_name,
   max_resources = NULL,
@@ -25,7 +30,7 @@ get_dataset <- function(
   check_dataset_name(dataset_name)
 
   # define query and try API call
-  query <- list("id" = dataset_name)
+  query <- list(id = dataset_name)
   content <- try(
     phs_GET("package_show", query),
     silent = TRUE
@@ -33,7 +38,7 @@ get_dataset <- function(
 
   # if content contains a 'Not Found Error'
   # throw error with suggested dataset name
-  if (grepl("Not Found Error", content[1])) {
+  if (grepl("Not Found Error", content[1L], fixed = TRUE)) {
     suggest_dataset_name(dataset_name)
   }
 
@@ -41,7 +46,7 @@ get_dataset <- function(
   all_ids <- purrr::map_chr(content$result$resources, ~ .x$id)
 
   n_res <- length(all_ids)
-  res_index <- 1:min(n_res, max_resources)
+  res_index <- 1L:min(n_res, max_resources)
 
   selection_ids <- all_ids[res_index]
 
@@ -51,22 +56,23 @@ get_dataset <- function(
     get_resource,
     rows = rows,
     row_filters = row_filters,
-    col_select = col_select,
+    col_select = col_select
   )
 
   # resolve class issues
   types <- purrr::map(
     all_data,
-    ~ purrr::map_chr(.x, class)
+    purrr::map_chr,
+    class
   )
 
   # for each df, check if next df class matches
-  inconsistencies <- vector(length = length(types) - 1, mode = "list")
+  inconsistencies <- vector(length = length(types) - 1L, mode = "list")
   for (i in seq_along(types)) {
     if (i == length(types)) break
 
     this_types <- types[[i]]
-    next_types <- types[[i + 1]]
+    next_types <- types[[i + 1L]]
 
     # find matching names
     matching_names <- suppressWarnings(
@@ -82,7 +88,7 @@ get_dataset <- function(
   # define which columns to coerce and warn
   to_coerce <- unique(names(unlist(inconsistencies)))
 
-  if (length(to_coerce) > 0) {
+  if (length(to_coerce) > 0L) {
     cli::cli_warn(c(
       "Due to conflicts between column types across resources,
       the following {cli::qty(to_coerce)} column{?s} ha{?s/ve} been coerced to type character:",
@@ -91,12 +97,10 @@ get_dataset <- function(
 
     all_data <- purrr::map(
       all_data,
-      ~ dplyr::mutate(
-        .x,
-        dplyr::across(
-          dplyr::any_of(to_coerce),
-          as.character
-        )
+      dplyr::mutate,
+      dplyr::across(
+        dplyr::any_of(to_coerce),
+        as.character
       )
     )
   }
@@ -105,14 +109,14 @@ get_dataset <- function(
     # Add the 'resource context' as columns to the data
     all_data <- purrr::pmap(
       list(
-        "data" = all_data,
-        "id" = selection_ids,
-        "name" = purrr::map_chr(content$result$resources[res_index], ~ .x$name),
-        "created_date" = purrr::map_chr(
+        data = all_data,
+        id = selection_ids,
+        name = purrr::map_chr(content$result$resources[res_index], ~ .x$name),
+        created_date = purrr::map_chr(
           content$result$resources[res_index],
           ~ .x$created
         ),
-        "modified_date" = purrr::map_chr(
+        modified_date = purrr::map_chr(
           content$result$resources[res_index],
           ~ .x$last_modified
         )
