@@ -10,8 +10,8 @@ test_that("throws error for non-existent res_ids", {
 test_that("downloads full resource", {
   data <- dump_download("a794d603-95ab-4309-8c92-b48970478c14")
 
-  expect_equal(nrow(data), 926)
-  expect_length(data, 15)
+  expect_identical(nrow(data), 926L)
+  expect_length(data, 15L)
   expect_named(data)
   expect_s3_class(data, "tbl_df")
 })
