@@ -1,8 +1,8 @@
 skip_if_offline(host = "www.opendata.nhs.scot")
 
 test_that("get_dataset returns data in the expected format", {
-  n_resources <- 2
-  n_rows <- 2
+  n_resources <- 2L
+  n_rows <- 2L
   data <- get_dataset(
     dataset_name = "gp-practice-populations",
     max_resources = n_resources,
@@ -10,14 +10,14 @@ test_that("get_dataset returns data in the expected format", {
   )
 
   expect_s3_class(data, "tbl_df")
-  expect_equal(nrow(data), n_resources * n_rows)
+  expect_identical(nrow(data), n_resources * n_rows)
   expect_named(data)
-  expect_gte(ncol(data), 4)
+  expect_gte(ncol(data), 4L)
 })
 
 test_that("get_dataset works properly with filters", {
-  n_resources <- 3
-  n_rows <- 10
+  n_resources <- 3L
+  n_rows <- 10L
   columns <- c("Date", "PracticeCode", "HSCP", "AllAges")
 
   data <- get_dataset(
@@ -29,7 +29,7 @@ test_that("get_dataset works properly with filters", {
   )
 
   expect_s3_class(data, "tbl_df")
-  expect_equal(nrow(data), n_resources * n_rows)
+  expect_identical(nrow(data), n_resources * n_rows)
   expect_named(data, columns)
   expect_true(all(data[["HSCP"]] == "S37000026"))
 })
@@ -57,7 +57,7 @@ test_that("get_dataset filters error properly", {
 })
 
 test_that("get_dataset works with multiple filters", {
-  n_resources <- 3
+  n_resources <- 3L
   columns <- c("Date", "PracticeCode", "HSCP", "AllAges")
 
   data <- get_dataset(
@@ -68,16 +68,16 @@ test_that("get_dataset works with multiple filters", {
   )
 
   expect_s3_class(data, "tbl_df")
-  expect_gte(nrow(data), n_resources * 4)
+  expect_gte(nrow(data), n_resources * 4L)
   expect_named(data, columns)
-  expect_true(all(data[["PracticeCode"]] %in% c("10002", "10017")))
+  expect_in(data[["PracticeCode"]], c("10002", "10017"))
 })
 
 test_that("Warns when having to coerce types", {
   expect_warning(
     coerced_data <- get_dataset(
       dataset_name = "nhsscotland-payments-to-general-practice",
-      rows = 1,
+      rows = 1L,
       col_select = "PracticeListSize"
     ),
     "Due to conflicts between column types across resources"
